@@ -13,12 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import eventlet
-
 from contextlib import contextmanager
-from neutron import context as ctx
-from neutron.i18n import _LE
+import os.path
 
+import eventlet
+from neutron_lib import context as ctx
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_service import loopingcall
@@ -78,6 +77,33 @@ class OVSDBManager(base_agent_manager.BaseAgentManager):
             ca_cert_path = self.conf.ovsdb.l2_gw_agent_ca_cert_base_path
             use_ssl = priv_key_path and cert_path and ca_cert_path
             if use_ssl:
+                LOG.debug("ssl is enabled with priv_key_path %s, cert_path "
+                          "%s, ca_cert_path %s", priv_key_path,
+                          cert_path, ca_cert_path)
+                priv_key_file = priv_key_path + "/" + ovsdb_identifier + ".key"
+                cert_file = cert_path + "/" + ovsdb_identifier + ".cert"
+                ca_cert_file = (ca_cert_path + "/" + ovsdb_identifier +
+                                ".ca_cert")
+                is_priv_key = os.path.isfile(priv_key_file)
+                is_cert_file = os.path.isfile(cert_file)
+                is_ca_cert_file = os.path.isfile(ca_cert_file)
+                if not is_priv_key:
+                    LOG.exception("Could not find private key in "
+                                  "%(path)s dir, expecting in the "
+                                  "file name %(file)s ",
+                                  {'path': priv_key_path,
+                                   'file': ovsdb_identifier + ".key"})
+                if not is_cert_file:
+                    LOG.exception("Could not find cert in %(path)s dir, "
+                                  "expecting in the file name %(file)s",
+                                  {'path': cert_path,
+                                   'file': ovsdb_identifier + ".cert"})
+                if not is_ca_cert_file:
+                    LOG.exception("Could not find cacert in %(path)s "
+                                  "dir, expecting in the file name "
+                                  "%(file)s",
+                                  {'path': ca_cert_path,
+                                   'file': ovsdb_identifier + ".ca_cert"})
                 ssl_ovsdb = {'use_ssl': True,
                              'private_key':
                                  "/".join([str(priv_key_path),
@@ -98,8 +124,8 @@ class OVSDBManager(base_agent_manager.BaseAgentManager):
             gateway = l2gateway_config.L2GatewayConfig(ovsdb_conf)
             self.gateways[ovsdb_identifier] = gateway
         except Exception as ex:
-            LOG.exception(_LE("Exception %(ex)s occurred while processing "
-                              "host %(host)s"), {'ex': ex, 'host': host})
+            LOG.exception("Exception %(ex)s occurred while processing "
+                          "host %(host)s", {'ex': ex, 'host': host})
 
     def _connect_to_ovsdb_server(self):
         """Initializes the connection to the OVSDB servers."""
@@ -120,8 +146,8 @@ class OVSDBManager(base_agent_manager.BaseAgentManager):
                         ovsdb_states[key] = 'disconnected'
                         # Log a warning and continue so that it can be
                         # retried in the next iteration.
-                        LOG.error(_LE("OVSDB server %s is not "
-                                      "reachable"), gateway.ovsdb_ip)
+                        LOG.error("OVSDB server %s is not "
+                                  "reachable", gateway.ovsdb_ip)
                         # Continue processing the next element in the list.
                         continue
                     gateway.ovsdb_fd = ovsdb_fd
@@ -182,8 +208,9 @@ class OVSDBManager(base_agent_manager.BaseAgentManager):
                   self.ovsdb_fd.check_monitor_table_thread) and (
                   self.ovsdb_fd.check_sock_rcv)):
                 for key in self.ovsdb_fd.ovsdb_dicts.keys():
-                    eventlet.greenthread.spawn_n(
-                        self.ovsdb_fd._spawn_monitor_table_thread, key)
+                    if key in self.ovsdb_fd.ovsdb_conn_list:
+                        eventlet.greenthread.spawn_n(
+                            self.ovsdb_fd._spawn_monitor_table_thread, key)
                 self._start_looping_task_ovsdb_states()
         elif ((self.enable_manager) and not (
               self.l2gw_agent_type == n_const.MONITOR)):
@@ -219,7 +246,7 @@ class OVSDBManager(base_agent_manager.BaseAgentManager):
             self.ovsdb_fd = ovsdb_common_class.OVSDB_commom_class(
                 self.conf.ovsdb,
                 gateway,
-                self.agent_to_plugin_rpc)
+                self.agent_to_plugin_rpc, self)
 
     @contextmanager
     def _open_connection(self, ovsdb_identifier):
@@ -248,15 +275,15 @@ class OVSDBManager(base_agent_manager.BaseAgentManager):
         elif ((self.enable_manager) and (
                 not self.l2gw_agent_type == n_const.MONITOR)):
             self._sock_open_connection()
-            self.ovsdb_fd._echo_response(ovsdb_identifier)
-            if self.ovsdb_fd.check_c_sock:
+            if ovsdb_identifier in self.ovsdb_fd.ovsdb_conn_list:
                 self.ovsdb_fd.delete_logical_switch(logical_switch_uuid,
                                                     ovsdb_identifier,
                                                     False)
         elif not self.enable_manager:
             if self._is_valid_request(ovsdb_identifier):
                 with self._open_connection(ovsdb_identifier) as ovsdb_fd:
-                    ovsdb_fd.delete_logical_switch(logical_switch_uuid)
+                    ovsdb_fd.delete_logical_switch(logical_switch_uuid,
+                                                   ovsdb_identifier)
 
     def add_vif_to_gateway(self, context, ovsdb_identifier,
                            logical_switch_dict, locator_dict,
@@ -270,18 +297,18 @@ class OVSDBManager(base_agent_manager.BaseAgentManager):
         elif ((self.enable_manager) and (
                 not self.l2gw_agent_type == n_const.MONITOR)):
             self._sock_open_connection()
-            self.ovsdb_fd._echo_response(ovsdb_identifier)
-            if self.ovsdb_fd.check_c_sock:
+            if ovsdb_identifier in self.ovsdb_fd.ovsdb_conn_list:
                 self.ovsdb_fd.insert_ucast_macs_remote(
                     logical_switch_dict,
                     locator_dict,
-                    mac_dict, ovsdb_identifier)
+                    mac_dict, ovsdb_identifier, False)
         elif not self.enable_manager:
             if self._is_valid_request(ovsdb_identifier):
                 with self._open_connection(ovsdb_identifier) as ovsdb_fd:
                     ovsdb_fd.insert_ucast_macs_remote(logical_switch_dict,
                                                       locator_dict,
-                                                      mac_dict)
+                                                      mac_dict,
+                                                      ovsdb_identifier)
 
     def delete_vif_from_gateway(self, context, ovsdb_identifier,
                                 logical_switch_uuid, mac):
@@ -293,15 +320,15 @@ class OVSDBManager(base_agent_manager.BaseAgentManager):
         elif ((self.enable_manager) and (
                 not self.l2gw_agent_type == n_const.MONITOR)):
             self._sock_open_connection()
-            self.ovsdb_fd._echo_response(ovsdb_identifier)
-            if self.ovsdb_fd.check_c_sock:
+            if ovsdb_identifier in self.ovsdb_fd.ovsdb_conn_list:
                 self.ovsdb_fd.delete_ucast_macs_remote(
                     logical_switch_uuid,
-                    mac, ovsdb_identifier)
+                    mac, ovsdb_identifier, False)
         elif not self.enable_manager:
             if self._is_valid_request(ovsdb_identifier):
                 with self._open_connection(ovsdb_identifier) as ovsdb_fd:
-                    ovsdb_fd.delete_ucast_macs_remote(logical_switch_uuid, mac)
+                    ovsdb_fd.delete_ucast_macs_remote(
+                        logical_switch_uuid, mac, ovsdb_identifier)
 
     def update_vif_to_gateway(self, context, ovsdb_identifier,
                               locator_dict, mac_dict):
@@ -316,20 +343,19 @@ class OVSDBManager(base_agent_manager.BaseAgentManager):
         elif ((self.enable_manager) and (
                 not self.l2gw_agent_type == n_const.MONITOR)):
             self._sock_open_connection()
-            self.ovsdb_fd._echo_response(ovsdb_identifier)
-            if self.ovsdb_fd.check_c_sock:
+            if ovsdb_identifier in self.ovsdb_fd.ovsdb_conn_list:
                 self.ovsdb_fd.update_ucast_macs_remote(locator_dict,
                                                        mac_dict,
-                                                       ovsdb_identifier)
+                                                       ovsdb_identifier, False)
         elif not self.enable_manager:
             if self._is_valid_request(ovsdb_identifier):
                 with self._open_connection(ovsdb_identifier) as ovsdb_fd:
-                    ovsdb_fd.update_ucast_macs_remote(locator_dict,
-                                                      mac_dict)
+                    ovsdb_fd.update_ucast_macs_remote(
+                        locator_dict, mac_dict, ovsdb_identifier)
 
     def update_connection_to_gateway(self, context, ovsdb_identifier,
                                      logical_switch_dict, locator_dicts,
-                                     mac_dicts, port_dicts):
+                                     mac_dicts, port_dicts, op_method):
         """Handle RPC cast from plugin.
 
         Handle RPC cast from plugin to connect/disconnect a network
@@ -341,17 +367,17 @@ class OVSDBManager(base_agent_manager.BaseAgentManager):
                                                        mac_dicts,
                                                        port_dicts,
                                                        ovsdb_identifier,
+                                                       op_method,
                                                        False)
         elif ((self.enable_manager) and (
                 not self.l2gw_agent_type == n_const.MONITOR)):
             self._sock_open_connection()
-            self.ovsdb_fd._echo_response(ovsdb_identifier)
-            if self.ovsdb_fd.check_c_sock:
+            if ovsdb_identifier in self.ovsdb_fd.ovsdb_conn_list:
                 self.ovsdb_fd.update_connection_to_gateway(
                     logical_switch_dict,
                     locator_dicts,
                     mac_dicts,
-                    port_dicts, ovsdb_identifier)
+                    port_dicts, ovsdb_identifier, op_method, False)
         elif not self.enable_manager:
             if self._is_valid_request(ovsdb_identifier):
                 with self._open_connection(ovsdb_identifier) as ovsdb_fd:
@@ -359,8 +385,10 @@ class OVSDBManager(base_agent_manager.BaseAgentManager):
                                                           locator_dicts,
                                                           mac_dicts,
                                                           port_dicts,
-                                                          ovsdb_identifier)
+                                                          ovsdb_identifier,
+                                                          op_method)
 
-    def agent_to_plugin_rpc(self, ovsdb_data):
+    def agent_to_plugin_rpc(self, activity, ovsdb_data):
         self.plugin_rpc.update_ovsdb_changes(ctx.get_admin_context(),
+                                             activity,
                                              ovsdb_data)
